# yaqd-core-python

[![PyPI version](https://badge.fury.io/py/yaqd-core.svg)](https://badge.fury.io/py/yaqd-core)

Core python package for implementing yaq daemons, and associated utilities.

Documentation at https://yaqd-core-python.yaq.fyi
